Ext.define('AS.ARC.apps.syslogServer.history.main', {
    extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'main',
	imgUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/images/',
	
	exportHistoryLog: function(exportFormat) {
		var page = this;

		var download = Ext.create('Ext.form.FormPanel', {
				items: [{xtype: 'filefield'}]
			}),
			uform = download.getForm();

		var doSubmit = function() {
			var exportParams = page.historyGrid.store.getProxy().extraParams,
				exportSortColumn = exportParams.sort,
				exportSortParam = exportParams.ascend;

			uform.submit({
				url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {
					act: 'History', 
					tab: 'Export_History', 
					sort: exportSortColumn, 
					ascend: exportSortParam, 
					format: exportFormat
				}),
				success: function(fp, o) {

				},
				failure: function(form, action) {
					var json = Ext.decode(action.response.responseText);
					AS.ARC.util.showMsgWindow({
						5000: _S('ERROR', 'SESSION_TIMEOUT'), 
						5005: _S('SYSLOG_SERVER', 'LOG_NO_DATA')
					}, json, page.fn.app.win);
				}
			});
		};

		doSubmit();
	},

	getPanel: function() {
		var page = this;
		
		var historyTopCt = Ext.create('AS.ARC.panelToolbarTop', {
			itemId: 'history-topct',
			layout: 'hbox',
			items: [
				{
					xtype: 'splitbutton',
					itemId: 'export',
					text: _S('SYSLOG_SERVER', 'EXPORT'),
					minWidth: 100,
					onClick: function() {
						var btn = this;

						// Menu would show at wrong position. If create at definition.
						// Because of this. Creating menu when btn be pressed.
						if (!btn.menu) {
							btn.menu = new Ext.menu.Menu({
								items: [{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'HTML'),
									icon: page.imgUrl + 'html-icon.png',
									handler: function() {
										var format = 'html';

										page.exportHistoryLog(format);
									}
								},
								{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'CSV'),
									icon: page.imgUrl + 'csv-icon.png',
									handler: function() {
										var format = 'csv';

										page.exportHistoryLog(format);
									}
								}]
							});
						}// end if
						btn.menu.showBy(btn, 'tl-bl');
					}
				},
				{
					xtype: 'button',
					itemId: 'clean',
					minWidth: 100,
					text: _S('COMMON', 'CLEAR'),
					handler: function() {
						var confirmWin = new AS.ARC.msgWindow({
							title: _S('COMMON', 'CONFIRMATION'),
							width: 400,
							parentWin: page.fn.app.win,
							iconType: 'question', // info, question, warning
							asItems: [{
								xtype: 'displayfield',
								value: _S('SYSTEMINFORMATION', 'NOTE_REMOVE_LOG')
							}],
							fbar: [
							{
								text: _S('COMMON', 'YES'),
								handler: function() {
									AS.ARC.ajax({
										url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'History', tab: 'Clean'}),
										method: 'post',
										success: function(json, opts) {
											page.historyGrid.store.load();
										},
										failure: function(json, opts) {

										}
									});
									confirmWin.close();
								},
								scope: this
							}, 
							{
								text: _S('COMMON', 'NO'),
								handler: function() {
									confirmWin.close();
								},
								scope: this
							}]
						});

						confirmWin.show();
					}
				}
			]
		});

		page.historyGrid = Ext.create('Ext.grid.GridPanel', {
			itemId: 'grid',
			height: 400,
			width: '100%',
			cls: 'as-grid',
			border: false,
			columns: [
				{
					dataIndex: 'time',
					flex: 2,
					header: _S('SYSLOG_SERVER', 'DAY_AND_TIME'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'msg',
					flex: 7,
					header: _S('HARDWARE', 'TEXT_MESSAGE'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}
			],
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				border: false
			})
		});
        
		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
            title: _S('SYSLOG_SERVER', 'HISTORY'),
			border: false,
			cls: 'as-page-panel',
			items: [
                historyTopCt,
				page.historyGrid
            ]
		};
	},

	getOriginStore: function() {
		var page = this;

		var historyStore = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			remoteSort: true,
			fields: [
				{name: 'time'},
				{name: 'msg'}
			],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {
					act: 'History',
					tab: 'List'
				}),
				reader: {
					type: 'json',
					root: 'list',
					totalProperty: 'count'
				},
				listeners: {
					exception: function (proxy, response, operation, opts) {
						var json = Ext.JSON.decode(response.responseText);
						AS.ARC.util.showMsgWindow({
							5000: _S('ERROR', 'SESSION_TIMEOUT')
						}, json, page.fn.app.win);
					}
				}
			},
			listeners: {
				beforeload: function() {
					page.historyGrid.el.mask(_S('COMMON','LOADING'));

					this.proxy.extraParams = {};

					var sorter = this.sorters.items[0],
						sortType = this.sorters.keys[0],
						sortDefaultValue = typeof sorter === 'undefined',
						sortColumn,
						sortParam;

					if (sortDefaultValue) {
						sortColumn = 0;
					} else if (sortType === 'msg') {
						sortColumn = 5;
					} else {
						sortColumn = 0;
					}

					if (sortDefaultValue) {
						sortParam = 0;
					} else if (sorter.direction === 'ASC') {
						sortParam = 1;
					} else {
						sortParam = 0;
					}

					Ext.apply(this.proxy.extraParams, {
						sort: sortColumn,
						ascend: sortParam
					});
				},
				load: function(store, records, successful, operation, eOpts) {
					page.historyGrid.dockedItems.getAt(1).bindStore(store);
					page.historyGrid.bindStore(store);
					page.historyGrid.view.el.dom.scrollTop = 0;
					if (page.isNeedToMoveFirstPage === true) {
						page.historyGrid.dockedItems.getAt(1).moveFirst();
						page.isNeedToMoveFirstPage = false;
					}
					page.historyGrid.el.unmask();
				}
			}
		});

		historyStore.load();
	},

	removeColumnsSortState: function() {
		var page = this;

		Ext.each(page.historyGrid.columns, function(column) {
			column.sortState = null;
			column.removeCls(["x-column-header-sort-ASC", "x-column-header-sort-DESC"]);
			column.sortable = true;
		});
	},

	loadData: function() {
		var page = this;

		page.isNeedToMoveFirstPage = true;
		page.getOriginStore();
		page.removeColumnsSortState();
	}
});

/**
 * @class AS.ARC.apps.syslogServer.history.fn
 * @extends AS.ARC.apps.syslogServer.fn
 * <p></p>
 */
Ext.define('AS.ARC.apps.syslogServer.history.fn', {
	extend: 'AS.ARC.apps.syslogServer.fn',

	fnTag: 'history',
	
	init: function (config) {
		this.apiUrl = AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi',
		this.createPanel();
	},
    
	createPanel: function () {
		var fn = this;
        
		var pageHistory = new AS.ARC.apps.syslogServer.history.main({fn: this});
			
		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageHistory.getPanel()
			],
			listeners: {
				tabchange: function(tabpanel) {
					var activeIndex = tabpanel.items.indexOf(tabpanel.getLayout().activeItem);
				},
				resize: function( main, adjWidth, adjHeight, eOpts ) {
					var newHeight = (AS.ARC.util.is4k() ? main.getHeight() - 250 : main.getHeight() - 150)
					main.down('#grid').setHeight(newHeight);
					Ps.update(this.el.dom.querySelector('.x-panel-body'));
				}
			}
		});
        
		fn.initMainPanel();
	},
	
	loadData: function () {
		this.tabPanel.activeTab.page.loadData(true);
	}
});