Ext.define('AS.ARC.apps.syslogServer.overview.log', {
	extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'log',
	getPanel: function () {
		var page = this;

		page.chartstore = Ext.create('Ext.data.Store', {
			fields: ['count', 'time', 'index'],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {
					act: 'Overview',
					tab: 'Statistics'
				}),
				reader: {
					type: 'json',
					root: 'data'
				}
			},
			params: {
				time: 5
			},
			sorters: [{ property: 'index', direction: 'DESC' }],
			listeners: {
				beforeload: function () {
					//logGrid.el.mask(_S('COMMON','LOADING'));
					//overview.items.get('chartcontainer').items.get('chart').el.mask(_S('COMMON', 'LOADING'));
				},
				load: function () {
					//logGrid.el.unmask();
					//overview.items.get('chartcontainer').items.get('chart').el.unmask();
				}
			}
		});



		page.statisticsChart = Ext.create('Ext.chart.Chart', {
			itemId: 'statisticschart',
			store: page.chartstore,
			width: 660,
			height: 425,
			minHeight: 425,
			minWidth: 550,
			theme: 'Category1',
			axes: [
				{
					title: _S('SYSLOG_SERVER', 'COUNT'),
					type: 'Numeric',
					position: 'left',
					fields: ['count'],
					minimum: 0,
					maximum: 10
				},
				{
					title: _S('SYSLOG_SERVER', 'PAST_SIX_MINUTES'),
					type: 'Category',
					position: 'bottom',
					fields: ['time']
				}
			],
			series: [
				{
					type: 'line',
					xField: 'time',
					yField: 'count'
				}
			],

			loadData: function (param) {


				if (param) {
					page.statisticsChart.store.load({
						scope: this,
						params: param,
						callback: function (records, operation, success) {

							var yAxis = page.statisticsChart.axes.items[0];
							var dataAry = [];

							Ext.each(records, function (record) {
								dataAry.push(record.data.count);
							})

							var max = dataAry.max();
							// set range of y axis, 50 100 500 1000,...
							if (max > 10) {
								var firstNum = parseInt(Math.floor(max / 10).toString().substr(0, 1)),
									pow = Math.pow(10, max.toString().length - 1);

								if (firstNum < 5) {
									yAxis.maximum = 5 * pow;
								} else {
									yAxis.maximum = 10 * pow;
								}
								page.statisticsChart.redraw();
							}


						}
					});
				} else {
					page.statisticsChart.store.load({
						scope: this,
						callback: function (records, operation, success) {

							var yAxis = page.statisticsChart.axes.items[0];
							var dataAry = [];

							Ext.each(records, function (record) {
								dataAry.push(record.data.count);
							})

							var max = dataAry.max();

							// set range of y axis, 50 100 500 1000,...
							if (max > 10) {
								var firstNum = parseInt(Math.floor(max / 10).toString().substr(0, 1)),
									pow = Math.pow(10, max.toString().length - 1);

								if (firstNum < 5) {
									yAxis.maximum = 5 * pow;
								} else {
									yAxis.maximum = 10 * pow;
								}
								page.statisticsChart.redraw();
							}


						}
					});
				}

			}
		});

		page.comboBox = Ext.create('Ext.form.field.ComboBox', {
			store: {
				fields: ['value', 'text'],
				data: [
					{ 'value': 5, 'text': _S('SYSLOG_SERVER', 'PAST_SIX_MINUTES') },
					{ 'value': 6, 'text': _S('SYSLOG_SERVER', 'PAST_ONE_HOUR') },
					{ 'value': 7, 'text': _S('SYSLOG_SERVER', 'PAST_SIX_HOURS') },
					{ 'value': 8, 'text': _S('SYSLOG_SERVER', 'PAST_ONE_DAY') }
				]
			},
			editable: false,
			value: '5',
			triggerAction: 'all',
			valueField: 'value',
			displayField: 'text',
			listeners: {
				change: function (combo, value) {
					var newParams;

					if (value == 5) {
						newParams = { time: 5 };
						page.statisticsChart.store.getProxy().extraParams = newParams;
						page.statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_SIX_MINUTES');

					} else if (value == 6) {
						newParams = { time: 6 };
						page.statisticsChart.store.getProxy().extraParams = newParams;
						page.statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_ONE_HOUR');
					} else if (value == 7) {
						newParams = { time: 7 };
						page.statisticsChart.store.getProxy().extraParams = newParams;
						page.statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_SIX_HOURS');
					} else {
						newParams = { time: 8 };
						page.statisticsChart.store.getProxy().extraParams = newParams;
						page.statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_ONE_DAY');
					}
					page.statisticsChart.loadData();
				}
			}
		});

		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
			title: _S('SYSLOG_SERVER', 'LOG_COUNT'),
			border: false,
			cls: 'as-page-panel',
			items: [
				page.comboBox,
				page.statisticsChart
			]
		};
	},

	loadData: function () {
		var page = this;

		page.statisticsChart.loadData({
			time: page.comboBox.getValue()
		});

		clearInterval(page.fn.statisticsChartId);

		page.fn.statisticsChartId = setInterval(function () {
			page.statisticsChart.loadData({
				time: page.comboBox.getValue()
			});
		}, 20000);
	}
});

Ext.define('AS.ARC.apps.syslogServer.overview.device', {
	extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'device',

	getPanel: function () {
		var page = this;

		var store = Ext.create('Ext.data.Store', {
			autoLoad: false,
			fields: ['count', 'fromhostname'],
			data: [{
				name: '',
				value: 100    // another value diferent to "0"
			}]
		});

		page.deviceChart = Ext.create('Ext.chart.Chart', {
			itemId: 'devicechart',
			width: 675,
			height: 425,
			border: 0,
			insetPadding: 60,
			shadow: false,
			store: store,
			legend: {
				position: 'right'
			},
			series: [
				{
					type: 'pie',
					field: 'count',
					showInLegend: true,
					donut: false,
					highlight: {
						segment: {
							margin: 20
						}
					},
					label: {
						field: 'fromhostname',
						//display: 'rotate',
						contrast: true,
						font: '12px Arial'
					}
				}
			]
		});

		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
			title: _S('SYSLOG_SERVER', 'VIEW_BY_DEVICE'),
			border: false,
			cls: 'as-page-panel',
			height: '100%',
			items: [
				page.deviceChart
			]
		};
	},
	loadData: function () {
		var page = this;
		clearInterval(page.fn.statisticsChartId);
		page.fn.loadPieChart(1, page.deviceChart);
	}
});

Ext.define('AS.ARC.apps.syslogServer.overview.level', {
	extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'level',

	getPanel: function () {
		var page = this;

		var levelstore = Ext.create('Ext.data.Store', {
			autoLoad: false,
			fields: ['count', 'level'],
			data: [{
				name: '',
				value: 100    // another value diferent to "0"
			}]
		});

		page.levelChart = Ext.create('Ext.chart.Chart', {
			itemId: 'levelchart',
			width: 675,
			height: 425,
			border: 0,
			insetPadding: 60,
			shadow: false,
			theme: 'Base:gradients',
			store: levelstore,
			legend: {
				position: 'right'
			},
			series: [
				{
					type: 'pie',
					field: 'count',
					showInLegend: true,
					donut: false,
					highlight: {
						segment: {
							margin: 20
						}
					},
					label: {
						field: 'level',
						//display: 'rotate',
						contrast: true,
						font: '12px Arial'
					}
				}
			],
			listeners: {
				afterrender: function (chart) {

					Ext.each(chart.legend.items, function (item) {
						item.un("mousedown", item.events.mousedown.listeners[0].fn);
					});


				}
			}
		});

		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
			title: _S('SYSLOG_SERVER', 'VIEW_BY_LEVEL'),
			border: false,
			cls: 'as-page-panel',
			height: '100%',
			items: [
				page.levelChart
			]
		};
	},
	loadData: function () {
		var page = this;
		clearInterval(page.fn.statisticsChartId);
		page.fn.loadPieChart(2, page.levelChart);
	}
});


/**
 * @class AS.ARC.apps.syslogServer.overview.fn
 * @extends AS.ARC.apps.syslogServer.fn
 * <p></p>
 */
Ext.define('AS.ARC.apps.syslogServer.overview.fn', {
	extend: 'AS.ARC.apps.syslogServer.fn',

	fnTag: 'overview',

	init: function (config) {
		this.apiUrl = AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi',

			this.createPanel();
		//this.loadData();
	},

	loadPieChart: function (activeIndex, chart) {

		var fn = this;

		if (activeIndex == 1) {

			//fn.panel.el.mask(_S('COMMON', 'LOADING'));
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', { act: 'Overview', tab: 'Group', group: 1 }),
				method: 'post',
				success: function (json, opts) {

					var ary = [];

					if (json.device.length != 0) {
						if (json.device.length > 4) {

							var count0 = json.device[0].count / json.count * 100;
							var count1 = json.device[1].count / json.count * 100;
							var count2 = json.device[2].count / json.count * 100;
							var otherCount = ((json.count - (json.device[0].count + json.device[1].count + json.device[2].count)) / json.count) * 100;

							if (count0 < 1) {
								count0 = 1;
							}

							if (count1 < 1) {
								count1 = 1;
							}

							if (count2 < 1) {
								count2 = 1;
							}

							if (otherCount < 1) {
								otherCount = 1;
							}

							if (json.device[0].count != 0) {
								ary.push({ count: count0, fromhostname: json.device[0].fromhostname + ' - ' + json.device[0].percentage + '%' });
							}

							if (json.device[1].count != 0) {
								ary.push({ count: count1, fromhostname: json.device[1].fromhostname + ' - ' + json.device[1].percentage + '%' });
							}

							if (json.device[2].count != 0) {
								ary.push({ count: count2, fromhostname: json.device[2].fromhostname + ' - ' + json.device[2].percentage + '%' });
							}

							if (json.count - (json.device[0].count + json.device[1].count + json.device[2].count) != 0) {
								ary.push({ count: otherCount, fromhostname: 'Others' + ' - ' + (100 - json.device[0].percentage - json.device[1].percentage - json.device[2].percentage).toFixed(2) + '%' });
							}

							chart.show();
							chart.store.loadData(ary, false);
							//fn.panel.el.unmask();

						} else {
							for (var i = 0; i < json.device.length; i++) {

								var count = json.device[i].count / json.count * 100;
								if (count < 1) {
									count = 1;
								}

								if (json.device[i].count != 0) {
									ary.push({ count: count, fromhostname: json.device[i].fromhostname + ' - ' + json.device[i].percentage + '%' });
								}
							}
							chart.ownerCt.el.unmask();
							chart.show();
							chart.store.loadData(ary, false);
							//fn.panel.el.unmask();
						}
					} else {
						chart.hide();
						chart.ownerCt.el.mask(_S('COMMON', 'EMPTY_NO_DATA'), 'as-mask-msg');
						//fn.panel.el.unmask();
					}
				},
				failure: function (json, opts) {

				}
			});
		} else if (activeIndex == 2) {
			fn.panel.el.mask(_S('COMMON', 'LOADING'));
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', { act: 'Overview', tab: 'Group', group: 0 }),
				method: 'post',
				success: function (json, opts) {

					var ary = [];

					var total = json.data[0].count + json.data[1].count + json.data[2].count + json.data[3].count;
					var cri = (json.data[0].count / total) * 100;
					var err = (json.data[1].count / total) * 100;
					var warn = (json.data[2].count / total) * 100;
					var info = (json.data[3].count / total) * 100;

					if (total != 0) {
						if (cri < 1) {
							cri = 1;
						}

						if (err < 1) {
							err = 1;
						}

						if (warn < 1) {
							warn = 1;
						}

						if (info < 1) {
							info = 1;
						}

						if (json.data[0].count != 0) {
							ary.push({ count: cri, level: json.data[0].level + ' - ' + json.data[0].percentage + '%' });
						}

						if (json.data[1].count != 0) {
							ary.push({ count: err, level: json.data[1].level + ' - ' + json.data[1].percentage + '%' });
						}

						if (json.data[2].count != 0) {
							ary.push({ count: warn, level: json.data[2].level + ' - ' + json.data[2].percentage + '%' });
						}

						if (json.data[3].count != 0) {
							ary.push({ count: info, level: json.data[3].level + ' - ' + json.data[3].percentage + '%' });
						}

						chart.ownerCt.el.unmask();
						chart.show();
						chart.store.loadData(ary, false);
						fn.panel.el.unmask();
					} else {
						chart.hide();
						chart.ownerCt.el.mask(_S('COMMON', 'EMPTY_NO_DATA'), 'as-mask-msg');
						fn.panel.el.unmask();
					}
				},
				failure: function (json, opts) {

				}
			});

		}
	},

	createPanel: function () {
		var fn = this;

		var pageLog = new AS.ARC.apps.syslogServer.overview.log({ fn: this }),
			pageDevice = new AS.ARC.apps.syslogServer.overview.device({ fn: this }),
			pageLevel = new AS.ARC.apps.syslogServer.overview.level({ fn: this });

		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageLog.getPanel(),
				pageDevice.getPanel(),
				pageLevel.getPanel()
			],
			listeners: {
				tabchange: function (tabpanel) {
					var activeIndex = tabpanel.items.indexOf(tabpanel.getLayout().activeItem);
					clearInterval(fn.statisticsChartId);
				},
				resize: function( main, adjWidth, adjHeight, eOpts ) {
					var newHeight = (AS.ARC.util.is4k() ? main.getHeight() - 250 : main.getHeight() - 150),
						newWidth = (AS.ARC.util.is4k() ? main.getWidth() - 100 : main.getWidth() - 50);

					main.down('#statisticschart').setHeight(newHeight);
					main.down('#devicechart').setHeight(newHeight);
					main.down('#levelchart').setHeight(newHeight);

					main.down('#statisticschart').setWidth(newWidth);
					main.down('#devicechart').setWidth(newWidth);
					main.down('#levelchart').setWidth(newWidth);

					Ps.update(this.el.dom.querySelector('.x-panel-body'));
				}
			}
		});

		//fn.tabPanel.enableDataConfirm();
		fn.initMainPanel();
	},

	loadData: function () {
		this.tabPanel.activeTab.page.loadData(true);
	},

	onClose: function () {
		var fn = this;
		clearInterval(fn.statisticsChartId);
	}
});